@@ -1,10 +1,10 @@
 /*
  *
- *  This file is part of MUMPS 5.4.1, released
- *  on Tue Aug  3 09:49:43 UTC 2021
+ *  This file is part of MUMPS 5.6.1, released
+ *  on Tue Jul 11 07:51:28 UTC 2023
  *
  *
- *  Copyright 1991-2021 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Copyright 1991-2023 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
  *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
@@ -48,17 +48,20 @@ extern "C" {
  * added if needed. */
 
 typedef LIBSEQ_INT MPI_Comm; /* Simple type for MPI communicator */
+typedef LIBSEQ_INT MPI_Fint; /* Simple type for MPI communicator */
 static MPI_Comm MPI_COMM_WORLD=(MPI_Comm)0;
 
 LIBSEQ_INT LIBSEQ_CALL MPI_Init(LIBSEQ_INT *pargc, char ***pargv);
-LIBSEQ_INT LIBSEQ_CALL MPI_Comm_rank(LIBSEQ_INT  comm, LIBSEQ_INT  *rank);
+LIBSEQ_INT LIBSEQ_CALL MPI_Comm_rank(MPI_Comm  comm, LIBSEQ_INT  *rank);
 LIBSEQ_INT LIBSEQ_CALL MPI_Finalize(void);
+MPI_Comm LIBSEQ_CALL MPI_Comm_f2c(LIBSEQ_INT comm);
 
 /* For MPI_IS_IN_PLACE tests */
 void LIBSEQ_CALL MUMPS_CHECKADDREQUAL(char *a, char*b, LIBSEQ_INT *i);
 void LIBSEQ_CALL MUMPS_CHECKADDREQUAL_(char *a, char*b, LIBSEQ_INT *i);
 void LIBSEQ_CALL mumps_checkaddrequal_(char *a, char*b, LIBSEQ_INT *i);
 void LIBSEQ_CALL mumps_checkaddrequal__(char *a, char*b, LIBSEQ_INT *i);
+double LIBSEQ_CALL MPI_Wtime();
 
 #ifdef __cplusplus
 }
